@@ -1,15 +1,16 @@
-import fastai2
-from fastai2.imports import *
-from fastai2.data.all import *
-from fastai2.torch_core import *
-from fastai2.learner import *
-from fastai2.metrics import *
-from fastai2.callback.all import *
-from fastai2.vision.data import *
-from fastai2.interpret import *
-from fastai2.optimizer import *
-from fastai2.torch_core import Module
-from fastai2.data.transforms import get_files
+import fastai
+from fastai.imports import *
+from fastai.data.all import *
+from fastai.torch_core import *
+from fastai.learner import *
+from fastai.metrics import *
+from fastai.callback.all import *
+from fastai.vision.data import *
+from fastai.interpret import *
+from fastai.optimizer import *
+from fastai.torch_core import Module
+from fastai.data.transforms import get_files
+from fastai.tabular.all import *
 import fastcore
 from fastcore.test import *
 from fastcore.utils import *
@@ -24,22 +25,26 @@ from numbers import Integral
 from pathlib import Path
 import time
 from time import gmtime, strftime
-from IPython.display import Audio, display, HTML, Javascript
-import tsai
+import pytz # timezone
+from IPython.display import Audio, display, HTML, Javascript, clear_output
+import warnings
+warnings.simplefilter(action='ignore', category=FutureWarning)
 
 PATH = Path(os.getcwd())
 device = 'cuda' if torch.cuda.is_available() else 'cpu'
 cpus = defaults.cpus
 
+
 def save_nb(verbose=False):
     display(Javascript('IPython.notebook.save_checkpoint()'))
     time.sleep(1)
     pv('\nCurrent notebook saved.\n', verbose)
 
-def last_saved(max_elapsed=10):
+
+def last_saved(max_elapsed=60):
     print('\n')
     lib_path = Path(os.getcwd()).parent
-    folder = lib_path/'tsai'
+    folder = lib_path / 'tsai'
     print('Checking folder:', folder)
     counter = 0
     elapsed = 0
@@ -47,30 +52,36 @@ def last_saved(max_elapsed=10):
     for fp in get_files(folder):
         fp = str(fp)
         fn = fp.split('/')[-1]
-        if not fn.endswith(".py") or fn.startswith("_") or fn.startswith(".") or fn in ['imports.py', 'all.py']: continue
+        if not fn.endswith(".py") or fn.startswith("_") or fn.startswith(
+                ".") or fn in ['imports.py', 'all.py']:
+            continue
         elapsed_time = current_time - os.path.getmtime(fp)
-        if elapsed_time > max_elapsed: 
+        if elapsed_time > max_elapsed:
             print(f"{fn:30} saved {elapsed_time:10.0f} s ago ***")
             counter += 1
         elapsed += elapsed_time
-    if counter == 0: 
+    if counter == 0:
         print('Correct conversion! 😃')
         output = 1
-    else: 
+    else:
         print('Incorrect conversion! 😔')
         output = 0
-    print(f'Total elapsed time {elapsed:.0f} s')
-    print(strftime("%a, %d %b %Y %H:%M:%S %Z\n"),"\n")
+    print(f'Total time elapsed {elapsed:.0f} s')
+    print(strftime("%A %D %T %Z"))
     return output
-    
-def beep(inp=1):
-    mult = 1.6*inp if inp else .08
-    wave = np.sin(mult*np.arange(1000))
-    return Audio(wave, rate=10000, autoplay=True)
 
-def create_scripts(max_elapsed=10):
+
+def beep(inp=1, duration=.1, n=1):
+    rate = 10000
+    mult = 1.6 * inp if inp else .08
+    wave = np.sin(mult*np.arange(rate*duration))
+    for i in range(n): 
+        display(Audio(wave, rate=10000, autoplay=True))
+        time.sleep(duration / .1)
+
+
+def create_scripts(max_elapsed=60):
     from nbdev.export import notebook2script
     save_nb()
     notebook2script()
-    return last_saved(max_elapsed)
-    
\ No newline at end of file
+    return last_saved(max_elapsed)
\ No newline at end of file
